==> voreen-src-4.4-win.zip: voreen-src-4.4-win/include/voreen/qt/widgets/property/floatmat2propertywidget.h <==
/***********************************************************************************
 *                                                                                 *
 * Voreen - The Volume Rendering Engine                                            *
 *                                                                                 *
 * Copyright (C) 2005-2013 University of Muenster, Germany.                        *
 * Visualization and Computer Graphics Group <http://viscg.uni-muenster.de>        *
 * For a list of authors please refer to the file "CREDITS.txt".                   *
 *                                                                                 *
 * This file is part of the Voreen software package. Voreen is free software:      *
 * you can redistribute it and/or modify it under the terms of the GNU General     *
 * Public License version 2 as published by the Free Software Foundation.          *
 *                                                                                 *
 * Voreen is distributed in the hope that it will be useful, but WITHOUT ANY       *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR   *
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.      *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License in the file   *
 * "LICENSE.txt" along with this file. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                                 *
 * For non-commercial academic use see the license exception specified in the file *
 * "LICENSE-academic.txt". To get information about commercial licensing please    *
 * contact the authors.                                                            *
 *                                                                                 *
 ***********************************************************************************/

#ifndef VRN_FLOATMAT2PROPTERYWIDGET_H
#define VRN_FLOATMAT2PROPTERYWIDGET_H

#include "voreen/core/properties/matrixproperty.h"

#include "voreen/qt/widgets/property/matrixpropertywidget.h"

#include <QWidget>

class QLineEdit;
class QDoubleValidator;

namespace voreen {

class FloatMat2PropertyWidget : public MatrixPropertyWidget {
Q_OBJECT
public:
    FloatMat2PropertyWidget(FloatMat2Property*, QWidget* = 0);

protected:
    virtual std::string getExtension() const { return "vm2"; }
    virtual void saveMatrix(const std::string& filename) const throw (SerializationException);
    virtual void loadMatrix(const std::string& filename) throw (SerializationException);

    FloatMat2Property* prop_;
    QDoubleValidator* doubleValidator_;
    QLineEdit* x0_;
    QLineEdit* y0_;
    QLineEdit* x1_;
    QLineEdit* y1_;

protected slots:
    virtual void updateFromPropertySlot();
    void updateValue();
    void identity();

};

}// namespace voreen

#endif // FLOATMAT2PROPTERYWIDGET_H

==> voreen-src-5.0.1-win.zip: voreen-src-5.0.1-win/include/voreen/qt/widgets/property/floatmat2propertywidget.h <==
/***********************************************************************************
 *                                                                                 *
 * Voreen - The Volume Rendering Engine                                            *
 *                                                                                 *
 * Copyright (C) 2005-2018 University of Muenster, Germany,                        *
 * Department of Computer Science.                                                 *
 * For a list of authors please refer to the file "CREDITS.txt".                   *
 *                                                                                 *
 * This file is part of the Voreen software package. Voreen is free software:      *
 * you can redistribute it and/or modify it under the terms of the GNU General     *
 * Public License version 2 as published by the Free Software Foundation.          *
 *                                                                                 *
 * Voreen is distributed in the hope that it will be useful, but WITHOUT ANY       *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR   *
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.      *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License in the file   *
 * "LICENSE.txt" along with this file. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                                 *
 * For non-commercial academic use see the license exception specified in the file *
 * "LICENSE-academic.txt". To get information about commercial licensing please    *
 * contact the authors.                                                            *
 *                                                                                 *
 ***********************************************************************************/

#ifndef VRN_FLOATMAT2PROPTERYWIDGET_H
#define VRN_FLOATMAT2PROPTERYWIDGET_H

#include "voreen/core/properties/matrixproperty.h"

#include "voreen/qt/widgets/property/matrixpropertywidget.h"

#include <QWidget>

class QLineEdit;
class QDoubleValidator;

namespace voreen {

class FloatMat2PropertyWidget : public MatrixPropertyWidget {
Q_OBJECT
public:
    FloatMat2PropertyWidget(FloatMat2Property*, QWidget* = 0);

protected:
    virtual std::string getExtension() const { return "vm2"; }
    virtual void saveMatrix(const std::string& filename) const;
    virtual void loadMatrix(const std::string& filename);

    FloatMat2Property* prop_;
    QDoubleValidator* doubleValidator_;
    QLineEdit* x0_;
    QLineEdit* y0_;
    QLineEdit* x1_;
    QLineEdit* y1_;

protected slots:
    virtual void updateFromPropertySlot();
    void updateValue();
    void identity();

};

}// namespace voreen

#endif // FLOATMAT2PROPTERYWIDGET_H
